package
module
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Apr 4, 2023
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func IPAddresses() (l []net.IP)
IPAddresses returns a list ip addresses
of the system's up network interfaces.
UpInterfaces returns a list of the system's up network interfaces,
optionally additional flags can be specified.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.