zero

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2022 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bytea28

func Bytea28(b *[28]byte)

Bytea28 clears the 28-byte (224 bits) array by filling it with the zero value. This is used to explicitly clear private key material from memory.

func Bytea32

func Bytea32(b *[32]byte)

Bytea32 clears the 32-byte (256 bits) array by filling it with the zero value. This is used to explicitly clear private key material from memory.

func Bytea64

func Bytea64(b *[64]byte)

Bytea64 clears the 64-byte (512 bits) array by filling it with the zero value. This is used to explicitly clear sensitive material from memory.

func Bytes

func Bytes(b []byte)

Bytes sets all bytes in the passed slice to zero. This is used to explicitly clear data from memory.

Types

This section is empty.

Jump to