network

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2022 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IPAddresses

func IPAddresses() (l []net.IP)

IPAddresses returns a list ip addresses of the system's up network interfaces.

func UpInterfaces

func UpInterfaces(fl ...net.Flags) (l []net.Interface)

UpInterfaces returns a list of the system's up network interfaces, optionally additional flags can be specified.

Types

This section is empty.

Jump to