Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Bytea28 ¶
func Bytea28(b *[28]byte)
Bytea28 clears the 28-byte (224 bits) array by filling it with the zero value. This is used to explicitly clear private key material from memory.
func Bytea32 ¶
func Bytea32(b *[32]byte)
Bytea32 clears the 32-byte (256 bits) array by filling it with the zero value. This is used to explicitly clear private key material from memory.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.